<?php

/*
 * Squelette : plugins/menus-22051-v1.7.26/menus/menu.html
 * Date :      Fri, 03 Jul 2020 06:39:58 GMT
 * Compile :   Thu, 16 Jul 2020 12:25:07 GMT
 * Boucles :   _menu_principal
 */ 

function BOUCLE_menu_principalhtml_270c78f6be155e58ff5e1cb1febad6bb(&$Cache, &$Pile, &$doublons, &$Numrows, $SP) {

	static $command = array();
	static $connect;
	$command['connect'] = $connect = '';
	if (!isset($command['table'])) {
		$command['table'] = 'menus';
		$command['id'] = '_menu_principal';
		$command['from'] = array('menus' => 'spip_menus');
		$command['type'] = array();
		$command['groupby'] = array();
		$command['select'] = array("menus.titre");
		$command['orderby'] = array();
		$command['join'] = array();
		$command['limit'] = '';
		$command['having'] = 
			array();
	}
	$command['where'] = 
			array(
			array('=', 'menus.id_menu', sql_quote(@$Pile[0]['id_menu'], '','bigint(21) NOT NULL AUTO_INCREMENT')));
	if (defined("_BOUCLE_PROFILER")) $timer = time()+(float)microtime();
	$t0 = "";
	// REQUETE
	$iter = IterFactory::create(
		"SQL",
		$command,
		array('plugins/menus-22051-v1.7.26/menus/menu.html','html_270c78f6be155e58ff5e1cb1febad6bb','_menu_principal',1,$GLOBALS['spip_lang'])
	);
	if (!$iter->err()) {
	$SP++;
	// RESULTATS
	while ($Pile[$SP]=$iter->fetch()) {

		$t0 .= (
'
<html>
	<head>
		' .
(($t1 = strval(interdire_scripts(textebrut(supprimer_numero(typo($Pile[$SP]['titre']), "TYPO", $connect, $Pile[0])))))!=='' ?
		('<title>' . $t1 . '</title>') :
		'') .
'
		<meta name="robots" content="none" />
	</head>
	<body>
		<h1>' .
interdire_scripts(supprimer_numero(typo($Pile[$SP]['titre']), "TYPO", $connect, $Pile[0])) .
'</h1>
		' .
recuperer_fond( 'inclure/menu' , array_merge($Pile[0],array()), array('compil'=>array('plugins/menus-22051-v1.7.26/menus/menu.html','html_270c78f6be155e58ff5e1cb1febad6bb','_menu_principal',9,$GLOBALS['spip_lang'])), _request('connect')) .
'</body>
</html>
');
	}
	$iter->free();
	}
	if (defined("_BOUCLE_PROFILER")
	AND 1000*($timer = (time()+(float)microtime())-$timer) > _BOUCLE_PROFILER)
		spip_log(intval(1000*$timer)."ms BOUCLE_menu_principal @ plugins/menus-22051-v1.7.26/menus/menu.html","profiler"._LOG_AVERTISSEMENT);
	return $t0;
}

//
// Fonction principale du squelette plugins/menus-22051-v1.7.26/menus/menu.html
// Temps de compilation total: 0.901 ms
//

function html_270c78f6be155e58ff5e1cb1febad6bb($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
BOUCLE_menu_principalhtml_270c78f6be155e58ff5e1cb1febad6bb($Cache, $Pile, $doublons, $Numrows, $SP) .
'
');

	return analyse_resultat_skel('html_270c78f6be155e58ff5e1cb1febad6bb', $Cache, $page, 'plugins/menus-22051-v1.7.26/menus/menu.html');
}
?>