<?php

/*
 * Squelette : ../prive/squelettes/top/plan.html
 * Date :      Sun, 21 Jun 2020 17:08:23 GMT
 * Compile :   Thu, 09 Jul 2020 07:14:06 GMT
 * Boucles :   
 */ 
//
// Fonction principale du squelette ../prive/squelettes/top/plan.html
// Temps de compilation total: 0.070 ms
//

function html_9472376386cfe06cfa3ec2ee04586198($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
'<h1>' .
_T('public|spip|ecrire:plan_site') .
'</h1>
' .
interdire_scripts((is_string('pleine_largeur')?vide($GLOBALS['largeur_ecran']='pleine_largeur'):(isset($GLOBALS['largeur_ecran'])?$GLOBALS['largeur_ecran']:''))));

	return analyse_resultat_skel('html_9472376386cfe06cfa3ec2ee04586198', $Cache, $page, '../prive/squelettes/top/plan.html');
}
?>