<?php

/*
 * Squelette : plugins/ckeditor-spip-plugin/spip-styles.js.html
 * Date :      Fri, 03 Jul 2020 11:43:34 GMT
 * Compile :   Thu, 09 Jul 2020 06:53:55 GMT
 * Boucles :   _si
 */ 

function BOUCLE_sihtml_02a4bf025d002599df590efdf89524bf(&$Cache, &$Pile, &$doublons, &$Numrows, $SP) {

	static $command = array();
	static $connect;
	$command['connect'] = $connect = '';
	if (!isset($si_init)) { $command['si'] = array(); $si_init = true; }
	$command['si'][] = interdire_scripts(invalideur_session($Cache, (table_valeur($GLOBALS["visiteur_session"], (string)'statut', null) < '2')));

	if (!isset($command['table'])) {
		$command['table'] = '';
		$command['id'] = '_si';
		$command['from'] = array();
		$command['type'] = array();
		$command['groupby'] = array();
		$command['select'] = array("count(*)");
		$command['orderby'] = array();
		$command['where'] = 
			array();
		$command['join'] = array();
		$command['limit'] = '';
		$command['having'] = 
			array();
	}
	if (defined("_BOUCLE_PROFILER")) $timer = time()+(float)microtime();
	$t0 = "";
	// REQUETE
	$iter = IterFactory::create(
		"CONDITION",
		$command,
		array('plugins/ckeditor-spip-plugin/spip-styles.js.html','html_02a4bf025d002599df590efdf89524bf','_si',2,$GLOBALS['spip_lang'])
	);
	if (!$iter->err()) {
	$Numrows['_si']['total'] = @intval($iter->count());
	$SP++;
	// RESULTATS
	
	$t0 = str_repeat('
<?php
	include_spip(\'inc/ckeditor_cfgtools\') ;
	include_spip(\'inc/ckeditor_lire_config\') ;
	include_spip(\'inc/ckeditor_constantes\') ;
	echo parse_spipcss(ckeditor_lire_config(\'styles\', _CKE_STYLES_DEF)) ;
?>
', $Numrows['_si']['total']);
	$iter->free();
	}
	if (defined("_BOUCLE_PROFILER")
	AND 1000*($timer = (time()+(float)microtime())-$timer) > _BOUCLE_PROFILER)
		spip_log(intval(1000*$timer)."ms BOUCLE_si @ plugins/ckeditor-spip-plugin/spip-styles.js.html","profiler"._LOG_AVERTISSEMENT);
	return $t0;
}

//
// Fonction principale du squelette plugins/ckeditor-spip-plugin/spip-styles.js.html
// Temps de compilation total: 16.051 ms
//

function html_02a4bf025d002599df590efdf89524bf($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
'<'.'?php header("X-Spip-Cache: 0"); ?'.'>'.'<'.'?php header("Cache-Control: no-cache, must-revalidate"); ?'.'><'.'?php header("Pragma: no-cache"); ?'.'>' .
'<'.'?php header(' . _q((	'Content-type: text/javascript' .
	(($t2 = strval(interdire_scripts($GLOBALS['meta']['charset'])))!=='' ?
			('; charset=' . $t2) :
			''))) . '); ?'.'>
' .
BOUCLE_sihtml_02a4bf025d002599df590efdf89524bf($Cache, $Pile, $doublons, $Numrows, $SP));

	return analyse_resultat_skel('html_02a4bf025d002599df590efdf89524bf', $Cache, $page, 'plugins/ckeditor-spip-plugin/spip-styles.js.html');
}
?>