<?php

/*
 * Squelette : ../plugins/ckeditor-spip-plugin/prive/squelettes/head/configurer_ckeditor.html
 * Date :      Fri, 03 Jul 2020 11:43:54 GMT
 * Compile :   Thu, 09 Jul 2020 08:18:39 GMT
 * Boucles :   
 */ 
//
// Fonction principale du squelette ../plugins/ckeditor-spip-plugin/prive/squelettes/head/configurer_ckeditor.html
// Temps de compilation total: 0.224 ms
//

function html_ebdd150d2a7e2c981ec69a0e03c6e5a8($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
recuperer_fond( 'prive/squelettes/head/dist' , array_merge($Pile[0],array()), array('compil'=>array('../plugins/ckeditor-spip-plugin/prive/squelettes/head/configurer_ckeditor.html','html_ebdd150d2a7e2c981ec69a0e03c6e5a8','',1,$GLOBALS['spip_lang'])), _request('connect')) .
'
' .
(($t1 = strval(produire_fond_statique( 'css/ckeditor.css' , array(), array('compil'=>array('../plugins/ckeditor-spip-plugin/prive/squelettes/head/configurer_ckeditor.html','html_ebdd150d2a7e2c981ec69a0e03c6e5a8','',2,$GLOBALS['spip_lang'])), _request('connect'))))!=='' ?
		('<link rel=\'stylesheet\' href=\'' . $t1 . '\' type=\'text/css\' />') :
		'') .
'
' .
recuperer_fond( 'prive/squelettes/head/configurer_ckeditor-v2' , array_merge($Pile[0],array()), array('compil'=>array('../plugins/ckeditor-spip-plugin/prive/squelettes/head/configurer_ckeditor.html','html_ebdd150d2a7e2c981ec69a0e03c6e5a8','',3,$GLOBALS['spip_lang'])), _request('connect')) .
'
');

	return analyse_resultat_skel('html_ebdd150d2a7e2c981ec69a0e03c6e5a8', $Cache, $page, '../plugins/ckeditor-spip-plugin/prive/squelettes/head/configurer_ckeditor.html');
}
?>