<?php

/*
 * Squelette : ../plugins-dist/urls_etendues/prive/squelettes/contenu/configurer_urls.html
 * Date :      Sun, 21 Jun 2020 17:06:36 GMT
 * Compile :   Mon, 28 Dec 2020 20:53:53 GMT
 * Boucles :   
 */ 
//
// Fonction principale du squelette ../plugins-dist/urls_etendues/prive/squelettes/contenu/configurer_urls.html
// Temps de compilation total: 4.514 ms
//

function html_1223f5cb0fe5843e0f26b6f680517cd8($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
'<h1 class="grostitre">' .
_T('urls:icone_configurer_urls') .
'</h1>


' .
executer_balise_dynamique('FORMULAIRE_CONFIGURER_URLS',
	array(),
	array('../plugins-dist/urls_etendues/prive/squelettes/contenu/configurer_urls.html','html_1223f5cb0fe5843e0f26b6f680517cd8','',4,$GLOBALS['spip_lang'])) .
'

<div class="ajax">
	' .
executer_balise_dynamique('FORMULAIRE_',
	array(interdire_scripts(choisir_form_configuration((include_spip('inc/config')?lire_config('type_urls',null,false):'')))),
	array('../plugins-dist/urls_etendues/prive/squelettes/contenu/configurer_urls.html','html_1223f5cb0fe5843e0f26b6f680517cd8','',7,$GLOBALS['spip_lang'])) .
'</div>');

	return analyse_resultat_skel('html_1223f5cb0fe5843e0f26b6f680517cd8', $Cache, $page, '../plugins-dist/urls_etendues/prive/squelettes/contenu/configurer_urls.html');
}
?>