<?php

/*
 * Squelette : squelettes/inclure/nav.html
 * Date :      Fri, 03 Jul 2020 08:01:52 GMT
 * Compile :   Thu, 27 Jul 2023 09:10:39 GMT
 * Boucles :   
 */ 
//
// Fonction principale du squelette squelettes/inclure/nav.html
// Temps de compilation total: 0.098 ms
//

function html_47156dc73730c617d81a0b8ae3044399($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = 
'<'.'?php echo recuperer_fond( ' . argumenter_squelette('inclure/barre-nav') . ', array_merge('.var_export($Pile[0],1).',array(\'identifiant\' => ' . argumenter_squelette('barrenav') . ',
	\'lang\' => ' . argumenter_squelette($GLOBALS["spip_lang"]) . ')), array("compil"=>array(\'squelettes/inclure/nav.html\',\'html_47156dc73730c617d81a0b8ae3044399\',\'\',1,$GLOBALS[\'spip_lang\'])), _request("connect"));
?'.'>';

	return analyse_resultat_skel('html_47156dc73730c617d81a0b8ae3044399', $Cache, $page, 'squelettes/inclure/nav.html');
}
?>