<?php

/*
 * Squelette : ../plugins/ckeditor-spip-plugin/css/ckeditor.css.html
 * Date :      Fri, 03 Jul 2020 11:43:35 GMT
 * Compile :   Thu, 09 Jul 2020 08:18:39 GMT
 * Boucles :   
 */ 
//
// Fonction principale du squelette ../plugins/ckeditor-spip-plugin/css/ckeditor.css.html
// Temps de compilation total: 0.156 ms
//

function html_d95bc7e3fb639c0ab286f6e9f96fec06($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
'<'.'?php header(' . _q('Content-Type: text/css; charset=iso-8859-15') . '); ?'.'>' .
'<'.'?php header(' . _q('Vary: Accept-Encoding') . '); ?'.'>
' .
vide($Pile['vars'][$_zzz=(string)'font-size'] = interdire_scripts(entites_html(sinon(table_valeur(@$Pile[0], (string)'font-size', null), '0.8125em'),true))) .
vide($Pile['vars'][$_zzz=(string)'line-height'] = interdire_scripts(entites_html(sinon(table_valeur(@$Pile[0], (string)'line-height', null), '1.385em'),true))) .
vide($Pile['vars'][$_zzz=(string)'margin-bottom'] = interdire_scripts(entites_html(sinon(table_valeur(@$Pile[0], (string)'margin-bottom', null), table_valeur($Pile["vars"], (string)'line-height', null)),true))) .
'li.niveau2 { 
	margin-left:50px;
	border-left:1px solid gray;
	border-bottom:1px solid gray;
}

li.niveau2 h3 {
	margin-bottom:0px;
	font-size:90%;
}

li.niveau2 fieldset {
	padding-bottom:0px;
}

');

	return analyse_resultat_skel('html_d95bc7e3fb639c0ab286f6e9f96fec06', $Cache, $page, '../plugins/ckeditor-spip-plugin/css/ckeditor.css.html');
}
?>