<?php

/*
 * Squelette : ../plugins/auto/saisies/v3.41.3/saisies/case.html
 * Date :      Thu, 25 Jun 2020 04:48:00 GMT
 * Compile :   Thu, 09 Jul 2020 08:18:40 GMT
 * Boucles :   
 */ 
//
// Fonction principale du squelette ../plugins/auto/saisies/v3.41.3/saisies/case.html
// Temps de compilation total: 0.782 ms
//

function html_fe7fbb67560b68130cb5635c23584c23($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
'
' .
vide($Pile['vars'][$_zzz=(string)'valeur'] = interdire_scripts((is_null(entites_html(sinon(table_valeur(@$Pile[0], (string)'valeur_forcee', null), interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'valeur', null),true))),true)) ? interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'defaut', null),true)):interdire_scripts(entites_html(sinon(table_valeur(@$Pile[0], (string)'valeur_forcee', null), interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'valeur', null),true))),true))))) .
(($t1 = strval(interdire_scripts(((entites_html(table_valeur(@$Pile[0], (string)'valeur_oui', null),true)) ?' ' :''))))!=='' ?
		($t1 . (	'
	' .
	vide($Pile['vars'][$_zzz=(string)'valeur'] = (in_array(table_valeur($Pile["vars"], (string)'valeur', null),array('on', interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'valeur_oui', null),true)))) ? interdire_scripts(entites_html(sinon(table_valeur(@$Pile[0], (string)'valeur_oui', null), 'on'),true)):interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'valeur_non', null),true)))))) :
		'') .
'
' .
(($t1 = strval(interdire_scripts(((entites_html(table_valeur(@$Pile[0], (string)'valeur_oui', null),true)) ?'' :' '))))!=='' ?
		($t1 . (	'
	' .
	vide($Pile['vars'][$_zzz=(string)'valeur'] = ((table_valeur($Pile["vars"], (string)'valeur', null) == 'on') ? interdire_scripts(entites_html(sinon(table_valeur(@$Pile[0], (string)'valeur_oui', null), 'on'),true)):interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'valeur_non', null),true)))))) :
		'') .
'
<div class="choix' .
(($t1 = strval(interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'class', null),true))))!=='' ?
		(' ' . $t1) :
		'') .
'">
	' .
(($t1 = strval(interdire_scripts(((entites_html(table_valeur(@$Pile[0], (string)'disable', null),true)) ?'' :' '))))!=='' ?
		($t1 . (	'<input type="hidden" name="' .
	interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'nom', null),true)) .
	'" value="' .
	interdire_scripts(entites_html(sinon(table_valeur(@$Pile[0], (string)'valeur_non', null), ''),true)) .
	'" />')) :
		'') .
'
	<input type="checkbox" name="' .
interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'nom', null),true)) .
'" class="checkbox" id="champ_' .
interdire_scripts(saisie_nom2classe(entites_html(sinon(table_valeur(@$Pile[0], (string)'id', null), interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'nom', null),true))),true))) .
'"' .
(((table_valeur($Pile["vars"], (string)'valeur', null) == interdire_scripts(entites_html(sinon(table_valeur(@$Pile[0], (string)'valeur_oui', null), 'on'),true))))  ?
		(' ' . ' checked="checked"') :
		'') .
' value="' .
interdire_scripts(entites_html(sinon(table_valeur(@$Pile[0], (string)'valeur_oui', null), 'on'),true)) .
'" ' .
(($t1 = strval(interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'disable', null),true))))!=='' ?
		(' disabled="' . $t1 . '"') :
		'') .
(($t1 = strval(interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'readonly', null),true))))!=='' ?
		(' readonly="' . $t1 . '"') :
		'') .
(($t1 = strval(interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'describedby', null),true))))!=='' ?
		(' aria-describedby="' . $t1 . '"') :
		'') .
(($t1 = strval(interdire_scripts(table_valeur(@$Pile[0], (string)'attributs', null))))!=='' ?
		(' ' . $t1) :
		'') .
(((((((('') AND (interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'obligatoire', null),true)))) ?' ' :'')) AND (interdire_scripts((entites_html(table_valeur(@$Pile[0], (string)'obligatoire', null),true) != 'non')))) ?' ' :''))  ?
		(' ' . ' required="required"') :
		'') .
'/>
	' .
(($t1 = strval(interdire_scripts(table_valeur(@$Pile[0], (string)'label_case', null))))!=='' ?
		((	'<label for="champ_' .
	interdire_scripts(saisie_nom2classe(entites_html(sinon(table_valeur(@$Pile[0], (string)'id', null), interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'nom', null),true))),true))) .
	'"' .
	(((table_valeur($Pile["vars"], (string)'valeur', null) == interdire_scripts(entites_html(sinon(table_valeur(@$Pile[0], (string)'valeur_oui', null), 'on'),true))))  ?
			(' ' . 'class="on"') :
			'') .
	'>') . $t1 . '</label>') :
		'') .
'
	' .
(($t1 = strval(interdire_scripts((((((entites_html(table_valeur(@$Pile[0], (string)'disable_avec_post', null),true)) AND (interdire_scripts((entites_html(table_valeur(@$Pile[0], (string)'disable_avec_post', null),true) != 'non')))) ?' ' :'')) ?' ' :''))))!=='' ?
		($t1 . (	'
		<input type="hidden" name="' .
	interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'nom', null),true)) .
	'" value="' .
	table_valeur($Pile["vars"], (string)'valeur', null) .
	'" />
	')) :
		'') .
'
</div>
');

	return analyse_resultat_skel('html_fe7fbb67560b68130cb5635c23584c23', $Cache, $page, '../plugins/auto/saisies/v3.41.3/saisies/case.html');
}
?>