<?php

/*
 * Squelette : ../plugins-dist/medias/prive/squelettes/contenu/popin-choisir_document.html
 * Date :      Sun, 21 Jun 2020 17:05:39 GMT
 * Compile :   Thu, 16 Jul 2020 08:04:16 GMT
 * Boucles :   
 */ 
//
// Fonction principale du squelette ../plugins-dist/medias/prive/squelettes/contenu/popin-choisir_document.html
// Temps de compilation total: 0.170 ms
//

function html_1d43036d718ab8f82c3f6b912f8dcfa6($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
'<div class="popin-choisir_document">
' .

'<'.'?php echo recuperer_fond( ' . argumenter_squelette('prive/squelettes/inclure/mediatheque-navigation') . ', array_merge('.var_export($Pile[0],1).',array(\'editable\' => ' . argumenter_squelette('non') . ',
	\'galerie\' => ' . argumenter_squelette('prive/squelettes/inclure/mediatheque-choisir') . ',
	\'lang\' => ' . argumenter_squelette($GLOBALS["spip_lang"]) . ')), array("compil"=>array(\'../plugins-dist/medias/prive/squelettes/contenu/popin-choisir_document.html\',\'html_1d43036d718ab8f82c3f6b912f8dcfa6\',\'\',2,$GLOBALS[\'spip_lang\']),\'ajax\' => ($v=( ' . argumenter_squelette(@$Pile[0]['ajax']) . '))?$v:true), _request("connect"));
?'.'>
</div>');

	return analyse_resultat_skel('html_1d43036d718ab8f82c3f6b912f8dcfa6', $Cache, $page, '../plugins-dist/medias/prive/squelettes/contenu/popin-choisir_document.html');
}
?>