<?php

/*
 * Squelette : plugins/menus-22051-v1.7.26/menus/menus/accueil.html
 * Date :      Fri, 03 Jul 2020 06:40:06 GMT
 * Compile :   Thu, 27 Jul 2023 09:10:39 GMT
 * Boucles :   
 */ 
//
// Fonction principale du squelette plugins/menus-22051-v1.7.26/menus/menus/accueil.html
// Temps de compilation total: 0.303 ms
//

function html_ad528447db216cb0dec0fe87ac249c16($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
vide($Pile['vars'][$_zzz=(string)'titre'] = interdire_scripts(((($a = typo(table_valeur(@$Pile[0], (string)'titre', null))) OR (is_string($a) AND strlen($a))) ? $a : _T('public|spip|ecrire:accueil_site')))) .
'
' .
(($t1 = strval(interdire_scripts(((entites_html(table_valeur(@$Pile[0], (string)'appel_formulaire', null),true)) ?' ' :''))))!=='' ?
		($t1 . (	'
	<div class="titre">' .
	table_valeur($Pile["vars"], (string)'titre', null) .
	'</div>
	<div class="infos">' .
	_T('public|spip|ecrire:info_racine_site') .
	'</div>
')) :
		'') .
'
' .
(($t1 = strval(interdire_scripts(((entites_html(table_valeur(@$Pile[0], (string)'appel_menu', null),true)) ?' ' :''))))!=='' ?
		($t1 . (	'
	' .
	vide($Pile['vars'][$_zzz=(string)'url'] = ancre_url(spip_htmlspecialchars(sinon($GLOBALS['meta']['adresse_site'],'.')),interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'ancre', null),true)))) .
	'<li class="menu-entree item menu-items__item menu-items__item_accueil' .
	(($t2 = strval(interdire_scripts(entites_html(table_valeur(@$Pile[0], (string)'css', null),true))))!=='' ?
			(' ' . $t2) :
			'') .
	(($t2 = strval(interdire_scripts((((((((((entites_html(table_valeur(@$Pile[0], (string)'env/type', null),true) == 'page')) AND (interdire_scripts((entites_html(table_valeur(@$Pile[0], (string)'env/composition', null),true) == 'sommaire')))) ?' ' :'')) OR (interdire_scripts((((entites_html(table_valeur(@$Pile[0], (string)'env/type-page', null),true) == 'sommaire')) ?' ' :'')))) ?' ' :'')) ?' ' :''))))!=='' ?
			($t2 . 'on active') :
			'') .
	'">
		<a href="' .
	table_valeur($Pile["vars"], (string)'url', null) .
	'" class="menu-items__lien">' .
	table_valeur($Pile["vars"], (string)'titre', null) .
	'</a>
')) :
		'') .
'
');

	return analyse_resultat_skel('html_ad528447db216cb0dec0fe87ac249c16', $Cache, $page, 'plugins/menus-22051-v1.7.26/menus/menus/accueil.html');
}
?>