<?php

/*
 * Squelette : plugins/ckeditor-spip-plugin/modeles/inc-aucun-document.html
 * Date :      Fri, 03 Jul 2020 11:43:40 GMT
 * Compile :   Thu, 16 Jul 2020 07:08:35 GMT
 * Boucles :   
 */ 
//
// Fonction principale du squelette plugins/ckeditor-spip-plugin/modeles/inc-aucun-document.html
// Temps de compilation total: 0.055 ms
//

function html_b6723d6ac7d9ea82c06c58e7e3962ac6($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
'<div style=\'margin:15px;\'>
	<h3>' .
_T('ckeditor:aucun_document') .
'</h3>
    ' .
_T('ckeditor:aucun_document_descriptif') .
'
    <div style=\'width:100%;text-align:center;\'><button onclick=\'window.close();\'>' .
_T('public|spip|ecrire:fermer_page') .
'</button></div>
</div>
');

	return analyse_resultat_skel('html_b6723d6ac7d9ea82c06c58e7e3962ac6', $Cache, $page, 'plugins/ckeditor-spip-plugin/modeles/inc-aucun-document.html');
}
?>