<?php

/*
 * Squelette : plugins/en_travaux-90326-v3.2.4/en_travaux/login_sos.html
 * Date :      Fri, 03 Jul 2020 06:40:14 GMT
 * Compile :   Wed, 08 Jul 2020 22:47:56 GMT
 * Boucles :   
 */ 
//
// Fonction principale du squelette plugins/en_travaux-90326-v3.2.4/en_travaux/login_sos.html
// Temps de compilation total: 233.751 ms
//

function html_c39183622d1bf9f48964f94468de3485($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
'<' . '?php header("X-Spip-Filtre: '.'compacte_head' . '"); ?'.'>
' .
'<'.'?php header(' . _q((	'Content-Type: text/html; charset=' .
	interdire_scripts($GLOBALS['meta']['charset']))) . '); ?'.'><!DOCTYPE html>
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="' .
spip_htmlentities(@$Pile[0]['lang'] ? @$Pile[0]['lang'] : $GLOBALS['spip_lang']) .
'" lang="' .
spip_htmlentities(@$Pile[0]['lang'] ? @$Pile[0]['lang'] : $GLOBALS['spip_lang']) .
'" dir="' .
lang_dir(@$Pile[0]['lang'], 'ltr','rtl') .
'">
<head>
<title>' .
interdire_scripts(textebrut(typo($GLOBALS['meta']['nom_site'], "TYPO", $connect, $Pile[0]))) .
'</title>
<meta http-equiv="Content-Type" content="text/html; charset=' .
interdire_scripts($GLOBALS['meta']['charset']) .
'" />
<meta name="robots" content="none" />
<meta name="generator" content="SPIP' .
(($t1 = strval(spip_version()))!=='' ?
		(' ' . $t1) :
		'') .
'" />
<link rel="stylesheet" href="' .
direction_css(find_in_theme('reset.css')) .
'" type="text/css" />
<link rel="stylesheet" href="' .
direction_css(find_in_theme('clear.css')) .
'" type="text/css" />
<link rel="stylesheet" href="' .
direction_css(find_in_theme('minipres.css')) .
'" type="text/css" />
' .
pipeline('insert_head_css','<!-- insert_head_css -->') .
'
<style type="text/css">
html { font-size: 100%; }
body { background: #fff url(' .
find_in_path('entravaux-bg.gif') .
'); text-align: left; font: 1em/normal Verdana,Geneva,sans-serif; color: #000; }
#minipres { width: 30em; margin: 26px; margin-left: 100px; }
#minipres h1 { font-size: 1.1em; color: #970038; font-weight: bold; }
</style>
' .
'<'.'?php header("X-Spip-Filtre: insert_head_css_conditionnel"); ?'.'>'. pipeline('insert_head','<!-- insert_head -->') .
'
<script type=\'text/javascript\'><!--
jQuery(function(){ jQuery(\'input#var_login\').focus();
jQuery(\'a#spip_pass\').click(function(){window.open(this.href, \'spip_pass\', \'scrollbars=yes, resizable=yes, width=480, height=330\'); return false;});
});
// --></script>
</head>
<body class="page_login" >
<div id="minipres">
	<h1>' .
interdire_scripts(typo($GLOBALS['meta']['nom_site'], "TYPO", $connect, $Pile[0])) .
'</h1>
	' .
(($t1 = strval((((((table_valeur(@$Pile[0], (string)'url', null)) ?'' :' ')) OR (match(table_valeur(@$Pile[0], (string)'url', null),(	'^(/.*/)?' .
		interdire_scripts(eval('return '.'_DIR_RESTREINT_ABS'.';')))))) ?' ' :'')))!=='' ?
		('
	' . $t1 . (	'
	<h1>' .
	_T('public|spip|ecrire:login_acces_prive') .
	'</h1>
	')) :
		'') .
'
	' .
executer_balise_dynamique('MENU_LANG_ECRIRE',
	array(spip_htmlentities(@$Pile[0]['lang'] ? @$Pile[0]['lang'] : $GLOBALS['spip_lang'])),
	array('plugins/en_travaux-90326-v3.2.4/en_travaux/login_sos.html','html_c39183622d1bf9f48964f94468de3485','',32,$GLOBALS['spip_lang'])) .
'

	' .
(($t1 = strval(interdire_scripts(invalideur_session($Cache, ((table_valeur($GLOBALS["visiteur_session"], (string)'statut', null)) ?' ' :'')))))!=='' ?
		($t1 . (	'
		<a href="' .
	interdire_scripts(entites_html(sinon(table_valeur(@$Pile[0], (string)'url', null), './'),true)) .
	'">' .
	_T('public|spip|ecrire:login_par_ici') .
	'</a>
	')) :
		'') .
'
	' .
(($t1 = strval(interdire_scripts(invalideur_session($Cache, ((table_valeur($GLOBALS["visiteur_session"], (string)'statut', null)) ?'' :' ')))))!=='' ?
		($t1 . (	'
		' .
	executer_balise_dynamique('FORMULAIRE_LOGIN',
	array(interdire_scripts(((($a = entites_html(table_valeur(@$Pile[0], (string)'url', null),true)) OR (is_string($a) AND strlen($a))) ? $a : generer_url_ecrire('accueil')))),
	array('plugins/en_travaux-90326-v3.2.4/en_travaux/login_sos.html','html_c39183622d1bf9f48964f94468de3485','',27,$GLOBALS['spip_lang'])) .
	'
	')) :
		'') .
'
	<p class="retour">
		' .
(($t1 = strval(tester_config(spip_htmlspecialchars(sinon($GLOBALS['meta']['adresse_site'],'.')),'1comite')))!=='' ?
		((	'&#91;<a href="' .
	interdire_scripts(generer_url_public('identifiants', 'focus=nom_inscription')) .
	'&amp;mode=') . $t1 . (	'" target="spip_pass" onclick="javascript:window.open(this.href, \'spip_pass\', \'scrollbars=yes, resizable=yes, width=480, height=400\'); return false;">' .
	_T('public|spip|ecrire:login_sinscrire') .
	'</a>&#93;')) :
		'') .
'
		&#91;<a href="' .
spip_htmlspecialchars(sinon($GLOBALS['meta']['adresse_site'],'.')) .
'/">' .
_T('public|spip|ecrire:login_retoursitepublic') .
'</a>&#93;
	</p>
	' .
(($t1 = strval(interdire_scripts(filtre_balise_img_dist(chemin_image('spip.png')))))!=='' ?
		((	'<p class="retour">
		<a href="https://www.spip.net/" title="' .
	_T('public|spip|ecrire:site_realise_avec_spip') .
	'">') . $t1 . '</a>
	</p>') :
		'') .
'
</div><!--#minipres-->
</body>
</html>');

	return analyse_resultat_skel('html_c39183622d1bf9f48964f94468de3485', $Cache, $page, 'plugins/en_travaux-90326-v3.2.4/en_travaux/login_sos.html');
}
?>