<?php

/*
 * Squelette : ../prive/squelettes/navigation/rubriques.html
 * Date :      Sun, 21 Jun 2020 17:08:22 GMT
 * Compile :   Thu, 09 Jul 2020 08:19:44 GMT
 * Boucles :   
 */ 
//
// Fonction principale du squelette ../prive/squelettes/navigation/rubriques.html
// Temps de compilation total: 0.143 ms
//

function html_c5d0f1a27245daf917221ac4c36d3834($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
'<div class="ajax">
' .
executer_balise_dynamique('FORMULAIRE_EDITER_LOGO',
	array('rubrique','0','',@serialize($Pile[0])),
	array('../prive/squelettes/navigation/rubriques.html','html_c5d0f1a27245daf917221ac4c36d3834','',2,$GLOBALS['spip_lang'])) .
'</div>
');

	return analyse_resultat_skel('html_c5d0f1a27245daf917221ac4c36d3834', $Cache, $page, '../prive/squelettes/navigation/rubriques.html');
}
?>