<?php

/*
 * Squelette : ../plugins/ckeditor-spip-plugin/prive/squelettes/navigation/configurer_ckeditor_p2.html
 * Date :      Fri, 03 Jul 2020 11:43:55 GMT
 * Compile :   Thu, 09 Jul 2020 08:18:55 GMT
 * Boucles :   
 */ 
//
// Fonction principale du squelette ../plugins/ckeditor-spip-plugin/prive/squelettes/navigation/configurer_ckeditor_p2.html
// Temps de compilation total: 0.085 ms
//

function html_21d3942b7ee622f3294d4b80dbdb8239($Cache, $Pile, $doublons = array(), $Numrows = array(), $SP = 0) {

	if (isset($Pile[0]["doublons"]) AND is_array($Pile[0]["doublons"]))
		$doublons = nettoyer_env_doublons($Pile[0]["doublons"]);

	$connect = '';
	$page = (
'
' .
recuperer_fond( 'prive/squelettes/inclure/menu-navigation' , array_merge($Pile[0],array('menu' => 'menu_configuration' ,
	'bloc' => 'navigation' )), array('compil'=>array('../plugins/ckeditor-spip-plugin/prive/squelettes/navigation/configurer_ckeditor_p2.html','html_21d3942b7ee622f3294d4b80dbdb8239','',2,$GLOBALS['spip_lang'])), _request('connect')));

	return analyse_resultat_skel('html_21d3942b7ee622f3294d4b80dbdb8239', $Cache, $page, '../plugins/ckeditor-spip-plugin/prive/squelettes/navigation/configurer_ckeditor_p2.html');
}
?>